==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/JwtParams.java <==

package me.snowdrop.istio.api.authentication.v1alpha1;

import java.io.Serializable;
import javax.validation.Valid;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "jwt"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = true, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class JwtParams implements Serializable, Params
{

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    @JsonPropertyDescription("")
    @Valid
    private Jwt jwt;
    private final static long serialVersionUID = -7370432778894011391L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public JwtParams() {
    }

    /**
     * 
     * @param jwt
     */
    public JwtParams(Jwt jwt) {
        super();
        this.jwt = jwt;
    }

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    public Jwt getJwt() {
        return jwt;
    }

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    public void setJwt(Jwt jwt) {
        this.jwt = jwt;
    }

}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/JwtParams.java <==

package me.snowdrop.istio.api.authentication.v1alpha1;

import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "jwt"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class JwtParams implements Serializable, Params
{

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    @JsonPropertyDescription("")
    private Jwt jwt;
    private final static long serialVersionUID = -7370432778894011391L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public JwtParams() {
    }

    /**
     * 
     * @param jwt
     */
    public JwtParams(Jwt jwt) {
        super();
        this.jwt = jwt;
    }

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    public Jwt getJwt() {
        return jwt;
    }

    /**
     * 
     * 
     */
    @JsonProperty("jwt")
    public void setJwt(Jwt jwt) {
        this.jwt = jwt;
    }

}
